==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/controllers/prehledzpracovane.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 23.01.2017
 */

namespace RonPortal\Editace;


use Ron\DB\DBUtils;
use Ron\Http\HtmlHeaders;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\TextViewObject;
use Ron\TextManager;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;


class PrehledZpracovaneController extends HttpController
{
    public $database;

    /**
     * PrehledZpracovaneController constructor.
     * @param $database
     */
    public function __construct($database)
    {
        $this->database = $database;
    }


    /**
     * @return PrehledZpracovaneDochazky
     * @throws \Exception
     */
    function prehledZpracovaneDochazky()
    {
        Model::addViewObject(new TextViewObject('<h1>' . \Ron\ronText('Prehled_zpracovane_dochazky') . '</h1>'));
        HtmlHeaders::getInstance() ->setTitle( \Ron\ronText('RON_Portal') . ' - ' . \Ron\ronText('Prehled_zpracovane_dochazky'));

        $filterForm = new RonPortalFilterForm($this ->database, 'prehledzpracovane', true);
        $filterForm ->nastavObdobi(true, 'ADS', false);

        $prava = Prava::vratPrava('prohlizeni');
        if ($prava ->zobrazitVyberRozdeleni()) { // napr. pro "pouze vlastni" se vyber nezobrazuje
            $filterForm ->nastavRozdeleni(true);
            $filterForm ->f_pravarozdeleni = $prava;

            if ( RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP)) $filterForm ->nastavRozdeleni2(true);
        }

        $filterForm ->loadData();

        Model::addViewObject($filterForm);

        $prehled = new PrehledZpracovaneDochazky($this ->database);

        // nacte nastaveni
        $settingsXml = DBUtils::getSqlValue($this ->database, "SELECT Val FROM SYS_BVAR_GLOBAL WHERE Name = 'RonPortal_Prehled_zpracovane'");
        if (!$settingsXml) {
            // puvodne se ukladalo primo v nastaveni portalu (11/2017 - presunuto do SYS_BVAR_GLOBAL) - pro kompatibilitu zkusi nacist stare nastaveni
            $settingsXml = RonPortalSettings::getMultilineValue('prehledzpracovane');
        }

        $prehled ->nactiNastaveni($settingsXml);
        $prehled ->load();
        return $prehled;
    }


    /**
     * @param string $action
     * @return \Ron\MVC\InternalRedirect|\Ron\MVC\OutputObject|\Ron\MVC\Redirect|\Ron\MVC\ViewObject|PrehledZpracovaneDochazky|string
     * @throws \Exception
     */
    public function handleAction($action)
    {
//    if (isset($_GET['action'])  &&  $_GET['action'] == 'report') {
//        return $this ->report();
//    }

        TextManager::getInstance() ->loadStrings('dochazka.ini');
        HtmlHeaders::getInstance() ->addScript('script/dochazka.js');
        HtmlHeaders::getInstance() ->addCss('css/dochazka.css');

//        if (isset($_POST['rozdelenidv']) && $_POST['rozdelenidv']) {
//            return $this ->rozdeleniDV();
//        }

        return $this ->prehledZpracovaneDochazky();
    }
}


return new PrehledZpracovaneController($this ->database);

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2305_171.zip: ronportal/controllers/prehledzpracovane.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 23.01.2017
 */

namespace RonPortal\Editace;


use Ron\DB\DBUtils;
use Ron\Http\HtmlHeaders;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\TextViewObject;
use Ron\TextManager;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;


class PrehledZpracovaneController extends HttpController
{
    public $database;

    /**
     * PrehledZpracovaneController constructor.
     * @param $database
     */
    public function __construct($database)
    {
        $this->database = $database;
    }


    /**
     * @return PrehledZpracovaneDochazky
     * @throws \Exception
     */
    function prehledZpracovaneDochazky()
    {
        Model::addViewObject(new TextViewObject('<h1>' . \Ron\ronText('Prehled_zpracovane_dochazky') . '</h1>'));
        HtmlHeaders::getInstance() ->setTitle( \Ron\ronText('RON_Portal') . ' - ' . \Ron\ronText('Prehled_zpracovane_dochazky'));

        $filterForm = new RonPortalFilterForm($this ->database, 'prehledzpracovane', true);
        $filterForm ->nastavObdobi(true, 'ADS', false);

        $prava = Prava::vratPrava('prohlizeni');
        if ($prava ->zobrazitVyberRozdeleni()) { // napr. pro "pouze vlastni" se vyber nezobrazuje
            $filterForm ->nastavRozdeleni(true);
            $filterForm ->f_pravarozdeleni = $prava;

            if ( RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP)) $filterForm ->nastavRozdeleni2(true);
        }

        $filterForm ->loadData();

        Model::addViewObject($filterForm);

        $prehled = new PrehledZpracovaneDochazky($this ->database);

        // nacte nastaveni
        $settingsXml = RonPortalSettings::getBvarSettings($this ->database,
            'RonPortal_Prehled_zpracovane',
            RonPortalSettings::getMultilineValue('prehledzpracovane'));

        $prehled ->nactiNastaveni($settingsXml);
        $prehled ->load();
        return $prehled;
    }


    /**
     * @param string $action
     * @return \Ron\MVC\InternalRedirect|\Ron\MVC\OutputObject|\Ron\MVC\Redirect|\Ron\MVC\ViewObject|PrehledZpracovaneDochazky|string
     * @throws \Exception
     */
    public function handleAction($action)
    {
//    if (isset($_GET['action'])  &&  $_GET['action'] == 'report') {
//        return $this ->report();
//    }

        TextManager::getInstance() ->loadStrings('dochazka.ini');
        HtmlHeaders::getInstance() ->addScript('script/dochazka.js');
        HtmlHeaders::getInstance() ->addCss('css/dochazka.css');

//        if (isset($_POST['rozdelenidv']) && $_POST['rozdelenidv']) {
//            return $this ->rozdeleniDV();
//        }

        return $this ->prehledZpracovaneDochazky();
    }
}


return new PrehledZpracovaneController($this ->database);
